@@ -32,7 +32,7 @@ sub delegation {
 
 sub hasWarnings {
     my ($self) = @_;
-    return $self->{hasWarnings};
+    return $self->{hasWarnings} ? 1 : 0;
 }
 
 sub gradeTrustIgnored {
@@ -154,5 +154,5 @@ indicates domain name delegation with and without the www prefix
 
 =head2 details
 
-this field contains an EndpointDetails object. It's not present by default, but can be enabled by using the "all" paramerer to the analyze API call.
+this field contains an L<Net::SSLLabs::EndpointDetails|Net::SSLLabs::EndpointDetails> object. It's not present by default, but can be enabled by using the "all" paramerer to the L<analyze|Net::SSLLabs/"analyze"> API call.
 
