@@ -63,17 +63,17 @@ sub serverSignature {
 
 sub prefixDelegation {
     my ($self) = @_;
-    return $self->{prefixDelegation};
+    return $self->{prefixDelegation} ? 1 : 0;
 }
 
 sub nonPrefixDelegation {
     my ($self) = @_;
-    return $self->{nonPrefixDelegation};
+    return $self->{nonPrefixDelegation} ? 1 : 0;
 }
 
 sub vulnBeast {
     my ($self) = @_;
-    return $self->{vulnBeast};
+    return $self->{vulnBeast} ? 1 : 0;
 }
 
 sub renegSupport {
@@ -93,7 +93,7 @@ sub stsMaxAge {
 
 sub stsSubdomains {
     my ($self) = @_;
-    return $self->{stsSubdomains};
+    return $self->{stsSubdomains} ? 1 : 0;
 }
 
 sub pkpResponseHeader {
@@ -113,7 +113,7 @@ sub compressionMethods {
 
 sub supportsNpn {
     my ($self) = @_;
-    return $self->{supportsNpn};
+    return $self->{supportsNpn} ? 1 : 0;
 }
 
 sub npnProtocols {
@@ -143,7 +143,7 @@ sub staplingRevocationErrorMessage {
 
 sub sniRequired {
     my ($self) = @_;
-    return $self->{sniRequired};
+    return $self->{sniRequired} ? 1 : 0;
 }
 
 sub httpStatusCode {
@@ -153,7 +153,7 @@ sub httpStatusCode {
 
 sub supportsRc4 {
     my ($self) = @_;
-    return $self->{supportsRc4};
+    return $self->{supportsRc4} ? 1 : 0;
 }
 
 sub forwardSecrecy {
@@ -163,7 +163,7 @@ sub forwardSecrecy {
 
 sub rc4WithModern {
     my ($self) = @_;
-    return $self->{rc4WithModern};
+    return $self->{rc4WithModern} ? 1 : 0;
 }
 
 sub sims {
@@ -173,12 +173,12 @@ sub sims {
 
 sub heartbleed {
     my ($self) = @_;
-    return $self->{heartbleed};
+    return $self->{heartbleed} ? 1 : 0;
 }
 
 sub heartbeat {
     my ($self) = @_;
-    return $self->{heartbeat};
+    return $self->{heartbeat} ? 1 : 0;
 }
 
 sub openSslCcs {
@@ -188,7 +188,7 @@ sub openSslCcs {
 
 sub poodle {
     my ($self) = @_;
-    return $self->{poodle};
+    return $self->{poodle} ? 1 : 0;
 }
 
 sub poodleTls {
@@ -198,12 +198,12 @@ sub poodleTls {
 
 sub fallbackScsv {
     my ($self) = @_;
-    return $self->{fallbackScsv};
+    return $self->{fallbackScsv} ? 1 : 0;
 }
 
 sub freak {
     my ($self) = @_;
-    return $self->{freak};
+    return $self->{freak} ? 1 : 0;
 }
 
 sub hasSct {
