@@ -58,7 +58,7 @@ sub engineVersion {
 
 sub isPublic {
     my ($self) = @_;
-    return $self->{isPublic};
+    return $self->{isPublic} ? 1 : 0;
 }
 
 sub protocol {
