@@ -17,7 +17,7 @@ sub strength {
 
 sub debianFlaw {
     my ($self) = @_;
-    return $self->{debianFlaw};
+    return $self->{debianFlaw} ? 1 : 0;
 }
 
 sub alg {
