@@ -23,7 +23,7 @@ sub list {
 
 sub preference {
     my ($self) = @_;
-    return $self->{preference};
+    return $self->{preference} ? 1 : 0;
 }
 
 1;
